@@ -18,13 +18,13 @@ typedef struct Media
 	QString totalTime;
 } Media;
 
-class UPlay;
+class Player;
 
 class Engine : public QObject
 {
 	Q_OBJECT
 	public:
-		Engine(UPlay *parent);
+		Engine(Player *parent);
 
 		~Engine();
 
@@ -59,7 +59,11 @@ class Engine : public QObject
 		{
 			audioOutput->setVolume(vol);
 		}
-
+		qint64 getCurrentTime()
+		{
+		  return mediaObject->currentTime();
+		}
+		void restoreState(int row, qint64 time);
 
 		/*
 		 * Add a media
@@ -70,6 +74,7 @@ class Engine : public QObject
 		 * Delete a media
 		 */
 		int delMedia(int row);
+		int moveMedia(int row, bool moveUp);
 
 		/*
 		 * Return info on a file
@@ -79,9 +84,11 @@ class Engine : public QObject
 		/*
 		 * Return the index of the currently played media
 		 */
-		int getCurrentPlayedMedia()
+		int getCurrentPlayedMedia();
+
+		void setCurrentPlayedMedia(int current)
 		{
-			return currentPlayedMedia;
+			currentPlayedMedia=current;
 		}
 
 		/*
@@ -89,6 +96,8 @@ class Engine : public QObject
 		 */
 		QString getUri(unsigned int row);
 		
+		int getNUris();
+		
 		/*
 		 * Clear every list : playlist, media list, uris list sources list
 		 */
@@ -121,6 +130,7 @@ class Engine : public QObject
 		void currentInfosUpdated(Phonon::State newState, Phonon::State oldState);
 		void refreshPlayedTime();
 		void playEnded();
+		void setInitialPosition(Phonon::State state);
 
 	private:		
 		int currentPlayedMedia;
@@ -142,9 +152,12 @@ class Engine : public QObject
 		QVector<QString> listUris;
 		Media tmpMedia;
 		
-		UPlay* parent;
+		Player* parent;
 		
 		int lastUpdated;
+		
+		qint64 init_position;
+		bool initial;
 };
 
 #endif
