@@ -28,10 +28,8 @@ class UIPlaylist : public QWidget
 		/*
 		 * Return the current selected row
 		 */
-		int currentRow()
-		{
-		  return widgetPlaylist->currentRow();
-		}
+		int currentRow();
+
 // 		void setCurrentRow(int row)
 // 		{
 // 		  widgetPlaylist->setCurrentRow(row);
@@ -52,7 +50,6 @@ class UIPlaylist : public QWidget
 		void clearPlaylist(); // clear the widget
 		void buttonClearPlaylist(); // clear the content & the widget
 		void playlistDoubleClicked();
-		void savePlaylist();
 		void delItem();
 		void upItem();
 		void downItem();
